analyzers subpackage
====================

This module is used to group all the analyzers of the webpage.

.. automodule:: wa_kat.analyzers
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   annotation_detector
   author_detector
   creation_date_detector
   keyword_detector
   language_detector
   place_detector
   title_detector

.. toctree::

   shared

.. toctree::

   source_string

